@@ -13,6 +13,7 @@ from UserDict import UserDict
 from celery import log
 from celery import conf
 from celery import registry as _registry
+from celery import platform
 from celery.utils.info import humanize_seconds
 
 
@@ -175,23 +176,27 @@ class ClockService(object):
         self.debug = log.SilenceRepeated(self.logger.debug,
                                          max_iterations=silence)
 
-    def start(self):
+    def start(self, embedded_process=False):
         self.logger.info("ClockService: Starting...")
         self.logger.debug("ClockService: "
             "Ticking with max interval->%s, schedule->%s" % (
                     humanize_seconds(self.max_interval),
                     self.schedule_filename))
 
+        if embedded_process:
+            platform.set_process_title("celerybeat")
+
         try:
-            while True:
-                if self._shutdown.isSet():
-                    break
-                interval = self.scheduler.tick()
-                self.debug("ClockService: Waking up %s." % (
-                        humanize_seconds(interval, prefix="in ")))
-                time.sleep(interval)
-        except (KeyboardInterrupt, SystemExit):
-            self.sync()
+            try:
+                while True:
+                    if self._shutdown.isSet():
+                        break
+                    interval = self.scheduler.tick()
+                    self.debug("ClockService: Waking up %s." % (
+                            humanize_seconds(interval, prefix="in ")))
+                    time.sleep(interval)
+            except (KeyboardInterrupt, SystemExit):
+                self.sync()
         finally:
             self.sync()
 
@@ -225,6 +230,37 @@ class ClockService(object):
         return self._scheduler
 
 
+class _Threaded(threading.Thread):
+    """Embedded clock service using threading."""
+
+    def __init__(self, *args, **kwargs):
+        super(_Threaded, self).__init__()
+        self.clockservice = ClockService(*args, **kwargs)
+        self.setDaemon(True)
+
+    def run(self):
+        self.clockservice.start()
+
+    def stop(self):
+        self.clockservice.stop(wait=True)
+
+
+class _Process(multiprocessing.Process):
+    """Embedded clock service using multiprocessing."""
+
+    def __init__(self, *args, **kwargs):
+        super(_Process, self).__init__()
+        self.clockservice = ClockService(*args, **kwargs)
+
+    def run(self):
+        platform.reset_signal("SIGTERM")
+        self.clockservice.start(embedded_process=True)
+
+    def stop(self):
+        self.clockservice.stop()
+        self.terminate()
+
+
 def EmbeddedClockService(*args, **kwargs):
     """Return embedded clock service.
 
@@ -232,35 +268,6 @@ def EmbeddedClockService(*args, **kwargs):
         Default is ``False``.
 
     """
-
-    class _Threaded(threading.Thread):
-        """Embedded clock service using threading."""
-
-        def __init__(self, *args, **kwargs):
-            super(_Threaded, self).__init__()
-            self.clockservice = ClockService(*args, **kwargs)
-            self.setDaemon(True)
-
-        def run(self):
-            self.clockservice.start()
-
-        def stop(self):
-            self.clockservice.stop(wait=True)
-
-    class _Process(multiprocessing.Process):
-        """Embedded clock service using multiprocessing."""
-
-        def __init__(self, *args, **kwargs):
-            super(_Process, self).__init__()
-            self.clockservice = ClockService(*args, **kwargs)
-            self.daemon = True
-
-        def run(self):
-            self.clockservice.start()
-
-        def stop(self):
-            self.clockservice.stop()
-
     if kwargs.pop("thread", False):
         # Need short max interval to be able to stop thread
         # in reasonable time.
