@@ -5,7 +5,7 @@
 
 .. cmdoption:: -s, --schedule
 
-    Path to the schedule database. Defaults to celerybeat-schedule.
+    Path to the schedule database. Defaults to ``celerybeat-schedule``.
     The extension ".db" will be appended to the filename.
 
 .. cmdoption:: -f, --logfile
@@ -67,7 +67,7 @@ def run_clockservice(loglevel=conf.CELERYBEAT_LOG_LEVEL,
     # Run the worker init handler.
     # (Usually imports task modules and such.)
     from celery.loaders import current_loader
-    current_loader().on_worker_init()
+    current_loader().init_worker()
 
 
     # Dump configuration to screen so we have some basic information
