@@ -135,11 +135,13 @@ class LoggingProxy(object):
                 def handleError(self, record):
                     exc_info = sys.exc_info()
                     try:
-                        traceback.print_exception(exc_info[0], exc_info[1],
-                                                  exc_info[2], None,
-                                                  sys.__stderr__)
-                    except IOError:
-                        pass    # see python issue 5971
+                        try:
+                            traceback.print_exception(exc_info[0],
+                                                      exc_info[1],
+                                                      exc_info[2],
+                                                      None, sys.__stderr__)
+                        except IOError:
+                            pass    # see python issue 5971
                     finally:
                         del(exc_info)
 
