@@ -4,6 +4,7 @@ Sending and Receiving Messages
 
 """
 import socket
+from datetime import datetime, timedelta
 
 from carrot.connection import DjangoBrokerConnection
 from carrot.messaging import Publisher, Consumer, ConsumerSet
@@ -16,13 +17,14 @@ from celery.utils import gen_unique_id, mitemgetter, noop
 
 MSG_OPTIONS = ("mandatory", "priority",
                "immediate", "routing_key",
-               "serializer")
+               "serializer", "delivery_mode")
 
 get_msg_options = mitemgetter(*MSG_OPTIONS)
 extract_msg_options = lambda d: dict(zip(MSG_OPTIONS, get_msg_options(d)))
 default_queue = conf.routing_table[conf.DEFAULT_QUEUE]
 
 _queues_declared = False
+_exchanges_declared = {}
 
 
 class TaskPublisher(Publisher):
@@ -31,6 +33,7 @@ class TaskPublisher(Publisher):
     exchange_type = default_queue["exchange_type"]
     routing_key = conf.DEFAULT_ROUTING_KEY
     serializer = conf.TASK_SERIALIZER
+    auto_declare = False
 
     def __init__(self, *args, **kwargs):
         super(TaskPublisher, self).__init__(*args, **kwargs)
@@ -41,14 +44,18 @@ class TaskPublisher(Publisher):
             consumers = get_consumer_set(self.connection)
             consumers.close()
             _queues_declared = True
+        if self.exchange not in _exchanges_declared:
+            self.declare()
+            _exchanges_declared[self.exchange] = True
 
     def delay_task(self, task_name, task_args=None, task_kwargs=None,
-            task_id=None, taskset_id=None, **kwargs):
+            countdown=None, eta=None, task_id=None, taskset_id=None, **kwargs):
         """Delay task for execution by the celery nodes."""
 
         task_id = task_id or gen_unique_id()
-        eta = kwargs.get("eta")
-        eta = eta and eta.isoformat()
+
+        if countdown: # Convert countdown to ETA.
+            eta = datetime.now() + timedelta(seconds=countdown)
 
         message_data = {
             "task": task_name,
@@ -56,7 +63,7 @@ class TaskPublisher(Publisher):
             "args": task_args or [],
             "kwargs": task_kwargs or {},
             "retries": kwargs.get("retries", 0),
-            "eta": eta,
+            "eta": eta and eta.isoformat(),
         }
 
         if taskset_id:
@@ -153,6 +160,7 @@ def get_consumer_set(connection, queues=None, **options):
     queues = queues or conf.routing_table
     cset = ConsumerSet(connection)
     for queue_name, queue_options in queues.items():
+        queue_options = dict(queue_options)
         queue_options["routing_key"] = queue_options.pop("binding_key", None)
         consumer = Consumer(connection, queue=queue_name,
                             backend=cset.backend, **queue_options)
