@@ -84,6 +84,17 @@ class Task(object):
 
         Override the global default ``exchange`` for this task.
 
+    .. attribute:: exchange_type
+
+        Override the global default exchange type for this task.
+
+    .. attribute:: delivery_mode
+
+        Override the global default delivery mode for this task.
+        By default this is set to ``2`` (persistent). You can change this
+        to ``1`` to get non-persistent behavior, which means the messages
+        are lost if the broker is restarted.
+
     .. attribute:: mandatory
 
         Mandatory message routing. An exception will be raised if the task
@@ -165,6 +176,8 @@ class Task(object):
     rate_limit = conf.DEFAULT_RATE_LIMIT
     rate_limit_queue_type = Queue
     backend = default_backend
+    exchange_type = conf.DEFAULT_EXCHANGE_TYPE
+    delivery_mode = conf.DEFAULT_DELIVERY_MODE
 
     MaxRetriesExceededError = MaxRetriesExceededError
 
@@ -180,8 +193,10 @@ class Task(object):
             * task_id
             * task_name
             * task_retries
+            * task_is_eager
             * logfile
             * loglevel
+            * delivery_info
 
         Additional standard keyword arguments may be added in the future.
         To take these default arguments, the task can either list the ones
@@ -208,7 +223,8 @@ class Task(object):
 
     @classmethod
     def get_publisher(self, connection=None, exchange=None,
-            connect_timeout=conf.BROKER_CONNECTION_TIMEOUT):
+            connect_timeout=conf.BROKER_CONNECTION_TIMEOUT,
+            exchange_type=None):
         """Get a celery task message publisher.
 
         :rtype: :class:`celery.messaging.TaskPublisher`.
@@ -223,9 +239,12 @@ class Task(object):
         """
         if exchange is None:
             exchange = self.exchange
+        if exchange_type is None:
+            exchange_type = self.exchange_type
         connection = connection or self.establish_connection(connect_timeout)
         return TaskPublisher(connection=connection,
                              exchange=exchange,
+                             exchange_type=exchange_type,
                              routing_key=self.routing_key)
 
     @classmethod
@@ -289,16 +308,19 @@ class Task(object):
         :keyword countdown: Time in seconds to delay the retry for.
         :keyword eta: Explicit time and date to run the retry at (must be a
             :class:`datetime.datetime` instance).
-        :keyword throw: If this is ``False``, do not raise the
-            :exc:`celery.exceptions.RetryTaskError` exception,
-            that tells the worker that the task is to be retried.
         :keyword \*\*options: Any extra options to pass on to
             meth:`apply_async`. See :func:`celery.execute.apply_async`.
+        :keyword throw: If this is ``False``, do not raise the
+            :exc:`celery.exceptions.RetryTaskError` exception,
+            that tells the worker to mark the task as being retried.
+            Note that this means the task will be marked as failed
+            if the task raises an exception, or successful if it
+            returns.
 
         :raises celery.exceptions.RetryTaskError: To tell the worker that the
-            task has been re-sent for retry. This always happens except if
+            task has been re-sent for retry. This always happens, unless
             the ``throw`` keyword argument has been explicitly set
-            to ``False``.
+            to ``False``, and is considered normal operation.
 
         Example
 
@@ -314,6 +336,10 @@ class Task(object):
             ...                        countdown=60 * 5, exc=exc)
 
         """
+        delivery_info = kwargs.pop("delivery_info", {})
+        options.setdefault("exchange", delivery_info.get("exchange"))
+        options.setdefault("routing_key", delivery_info.get("routing_key"))
+
         options["retries"] = kwargs.pop("task_retries", 0) + 1
         options["task_id"] = kwargs.pop("task_id", None)
         options["countdown"] = options.get("countdown",
@@ -554,9 +580,8 @@ class TaskSet(object):
         finally:
             publisher.close()
             conn.close()
-        result = TaskSetResult(taskset_id, subtasks)
 
-        return result
+        return TaskSetResult(taskset_id, subtasks)
 
     def apply_part(self, arglist, taskset_id, publisher):
         args, kwargs, opts = padlist(arglist, 3, default={})
@@ -693,7 +718,7 @@ class PeriodicTask(Task):
                       5: lambda x: x / 60}
         args = dt.year, dt.month, dt.day, dt.hour, dt.minute, dt.second
         r = None
-        for res, calc in resolution.items():
-            if calc(self.timedelta_seconds(delta)):
+        for res, predicate in resolution.items():
+            if predicate(self.timedelta_seconds(delta)):
                 r = res
         return datetime(*args[:r])
