@@ -1,3 +1,4 @@
+from __future__ import generators
 """
 
 Utility functions
@@ -11,7 +12,7 @@ except ImportError:
     ctypes = None
 from uuid import UUID, uuid4, _uuid_generate_random
 from inspect import getargspec
-from itertools import repeat, islice
+from itertools import islice
 
 from billiard.utils.functional import curry
 
@@ -75,7 +76,7 @@ def padlist(container, size, default=None):
         ("George", "Constanza", "NYC", "Earth")
 
     """
-    return container[:size] + [default] * (size - len(container))
+    return list(container)[:size] + [default] * (size - len(container))
 
 
 def mitemgetter(*items):
