@@ -7,6 +7,7 @@ import socket
 import logging
 import traceback
 from Queue import Queue
+from multiprocessing.util import Finalize
 
 from celery import conf
 from celery import registry
@@ -14,6 +15,7 @@ from celery import platform
 from celery import signals
 from celery.log import setup_logger, _hijack_multiprocessing_logger
 from celery.beat import EmbeddedClockService
+from celery.utils import noop
 
 from celery.worker.pool import TaskPool
 from celery.worker.buckets import TaskBucket
@@ -27,8 +29,16 @@ def process_initializer():
     # when detached, where the worker gets EOFErrors from time to time
     # and the logger is left from the parent process causing a crash.
     _hijack_multiprocessing_logger()
+
+    platform.reset_signal("SIGTERM")
     platform.set_mp_process_title("celeryd")
 
+    # This is for windows and other platforms not supporting
+    # fork(). Note that init_worker makes sure it's only
+    # run once per process.
+    from celery.loaders import current_loader
+    current_loader().init_worker()
+
 
 class WorkController(object):
     """Executes tasks waiting in the task queue.
@@ -103,7 +113,8 @@ class WorkController(object):
 
     def __init__(self, concurrency=None, logfile=None, loglevel=None,
             send_events=conf.SEND_EVENTS, hostname=None,
-            embed_clockservice=False):
+            ready_callback=noop, embed_clockservice=False,
+            schedule_filename=conf.CELERYBEAT_SCHEDULE_FILENAME):
 
         # Options
         self.loglevel = loglevel or self.loglevel
@@ -112,7 +123,9 @@ class WorkController(object):
         self.logger = setup_logger(loglevel, logfile)
         self.hostname = hostname or socket.gethostname()
         self.embed_clockservice = embed_clockservice
+        self.ready_callback = ready_callback
         self.send_events = send_events
+        self._finalize = Finalize(self, self.stop, exitpriority=20)
 
         # Queues
         if conf.DISABLE_RATE_LIMITS:
@@ -135,14 +148,16 @@ class WorkController(object):
 
         self.clockservice = None
         if self.embed_clockservice:
-            self.clockservice = EmbeddedClockService(logger=self.logger)
+            self.clockservice = EmbeddedClockService(logger=self.logger,
+                                    schedule_filename=schedule_filename)
 
-        prefetch_count = concurrency * conf.CELERYD_PREFETCH_MULTIPLIER
+        prefetch_count = self.concurrency * conf.CELERYD_PREFETCH_MULTIPLIER
         self.listener = CarrotListener(self.ready_queue,
                                        self.eta_schedule,
                                        logger=self.logger,
                                        hostname=self.hostname,
-                                       send_events=send_events,
+                                       send_events=self.send_events,
+                                       init_callback=self.ready_callback,
                                        initial_prefetch_count=prefetch_count)
 
         # The order is important here;
@@ -184,6 +199,25 @@ class WorkController(object):
             return
 
         signals.worker_shutdown.send(sender=self)
-        [component.stop() for component in reversed(self.components)]
+        for component in reversed(self.components):
+            self.logger.debug("Stopping thread %s..." % (
+                              component.__class__.__name__))
+            component.stop()
 
+        self.listener.close_connection()
+        self._state = "STOP"
+
+    def terminate(self):
+        """Not so gracefully shutdown the worker server."""
+        if self._state != "RUN":
+            return
+
+        signals.worker_shutdown.send(sender=self)
+        for component in reversed(self.components):
+            self.logger.debug("Terminating thread %s..." % (
+                              component.__class__.__name__))
+            terminate = getattr(component, "terminate", component.stop)
+            terminate()
+
+        self.listener.close_connection()
         self._state = "STOP"
